spoon.spooncore.Memoizer

Package spoon :: Module spooncore :: Class Memoizer |
[hide private]
[frames] | no frames]

# Class Memoizer

source code

    object --+
             |
            Memoizer

Used as a substitute for the file object when serializing Serial objects, so reference cycles are caught and handled.

Instance Methods | [hide private]
`` | __init__(self, fd) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
`` | write(self, data)
`` | read(self, n)
`` | __getattr__(self, name)
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, fd) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### write(self, data) | source code
None

### read(self, n) | source code
None

### __getattr__(self, name) (Qualification operator) | source code
None